#!/bin/sh
#################################################################
#								#
#  sybinstall.sh	Sybase Adaptive Server Enterprise	#
#								#
#  Script to administrate and configure your Sybase ASE		#
#  installation for the 1st time.  Create a system account	#
#  and have installation permissions set to the release.	#
#								#
#  RPM can tell us where the ASE components are installed.	#
#  queryformat on the 'installprefix' will provide the		#
#  correct location if it was relocated into an other area.	#
#								#
#################################################################
export PATH="/etc:/bin:/sbin:/usr/bin:/usr/sbin:$PATH"

# Are we invoked with an argument (RPM native) or is this a manual request.
if [ "${1}" ]; then
    if [ -f $1/install/sybinstall.sh ]; then
	export SYBASE=$1
    fi
else
    export SYBASE=`rpm -q --queryformat '%{installprefix}' sybase-common`
fi

if [ "${SYBASE}" ]; then

    ID=`id -u`
    if [ ${ID} -ne 0 ]; then
	echo "This script needs to be ran by root"
	exit 1
    fi

    # Profide a sybase boot script under /etc/rc.d/init.d.
    if [ ! -f /etc/rc.d/init.d/sybase -a -d /etc/rc.d/init.d ]; then
	cp ${SYBASE}/install/rc.sybase /etc/rc.d/init.d/sybase
    	chmod 555 /etc/rc.d/init.d/sybase
    fi

    # Provide a .profile and .cshrc from the install directory.
    cp ${SYBASE}/install/profile ${SYBASE}/.profile
    cp ${SYBASE}/install/cshrc ${SYBASE}/.cshrc

    # Provide execute permissions on the above scripts.
    chmod 755 ${SYBASE}/.profile ${SYBASE}/.cshrc

    # Is this a NIS based installation, yes -> use ypmatch over grep
    ypwhich > /dev/null 2>&1
    NIS_INSTALL=$?

    if [ ${NIS_INSTALL} = 0 ]; then

	SYB_GROUP=`ypmatch "sybase" group | grep "^sybase"` > /dev/null
	SYB_USER=`ypmatch "sybase" passwd | grep "^sybase"` > /dev/null

    else

	SYB_GROUP=`grep "^sybase" /etc/group` > /dev/null
	SYB_USER=`grep "^sybase" /etc/passwd` > /dev/null

    fi

    if [ ! "${SYB_GROUP}" ]; then
	groupadd sybase
    fi
    chgrp sybase ${SYBASE} ${SYBASE}/install \
		${SYBASE}/init/* ${SYBASE}/sample/*
    chmod g+w ${SYBASE} ${SYBASE}/install \
		${SYBASE}/init/* ${SYBASE}/sample/*

    if [ ! "${SYB_USER}" ]; then
	useradd -g sybase -d ${SYBASE} \
		-c "Sybase ASE DBA account" sybase
	rm -f ${SYBASE}/.bash*
    fi
    chown sybase ${SYBASE} ${SYBASE}/install ${SYBASE}/init/*

    # Owner changes required on post Replication Server installs
    if [ -d ${SYBASE}/REP-12_0/init/logs ]; then
	chown sybase ${SYBASE}/REP-12_0/init/logs
    fi
    if [ -d ${SYBASE}/RSM-12_0/admin ]; then
	chown -R sybase ${SYBASE}/RSM-12_0/admin
    fi

    # Owner changes required on post DEMO ASE Server installs
    if [ -d ${SYBASE}/sysam/licenses -a -x ${SYBASE}/install/demokey.sh ]; then
	chown -R sybase ${SYBASE}/sysam/licenses
	${SYBASE}/install/demokey.sh verify
    fi

    # Indicate that the readme and srvbuild process can be triggered.
    touch ${SYBASE}/.readme ${SYBASE}/.srvbuild

    exit 0
fi

exit 1
